.. _example-docs:

Examples
========

PyMoskito comes with quite a set of interesting examples from the field of
control theory. To run an example just enter::

  $ python -m pymoskito.examples.NAME

where ``NAME`` is the name, given in parenthesis behind the example titles.


List of Examples:

.. toctree::
  :maxdepth: 1

  ballbeam
  balltube/balltube
  pendulum
  car
  tanksystem
